@@ -54,23 +54,6 @@ else
 fi
 iniset $TEMPEST_CONFIG share backend_names $BACKENDS_NAMES
 
-# If testing a stable branch, we need to ensure we're testing with supported
-# API micro-versions; so set the versions from code if we're not testing the
-# master branch. If we're testing master, we'll allow manila-tempest-plugin
-# (which is branchless) tell us what versions it wants to test.
-if [[ $ZUUL_BRANCH != "master" ]]; then
-    # Grab the supported API micro-versions from the code
-    _API_VERSION_REQUEST_PATH=$BASE/new/manila/manila/api/openstack/api_version_request.py
-    _DEFAULT_MIN_VERSION=$(awk '$0 ~ /_MIN_API_VERSION = /{print $3}' $_API_VERSION_REQUEST_PATH)
-    _DEFAULT_MAX_VERSION=$(awk '$0 ~ /_MAX_API_VERSION = /{print $3}' $_API_VERSION_REQUEST_PATH)
-    # Override the *_api_microversion tempest options if present
-    MANILA_TEMPEST_MIN_API_MICROVERSION=${MANILA_TEMPEST_MIN_API_MICROVERSION:-$_DEFAULT_MIN_VERSION}
-    MANILA_TEMPEST_MAX_API_MICROVERSION=${MANILA_TEMPEST_MAX_API_MICROVERSION:-$_DEFAULT_MAX_VERSION}
-    # Set these options in tempest.conf
-    iniset $TEMPEST_CONFIG share min_api_microversion $MANILA_TEMPEST_MIN_API_MICROVERSION
-    iniset $TEMPEST_CONFIG share max_api_microversion $MANILA_TEMPEST_MAX_API_MICROVERSION
-fi
-
 # Set two retries for CI jobs
 iniset $TEMPEST_CONFIG share share_creation_retry_number 2
 
@@ -363,11 +346,9 @@ echo "Manila service details"
 source $BASE/new/devstack/openrc admin admin
 manila service-list
 
-echo "Running tempest manila test suites"
 cd $BASE/new/tempest/
-# List plugins in logs to enable debugging
-sudo -H -u $USER tempest list-plugins
-sudo -H -u $USER tempest run -r $MANILA_TESTS --concurrency=$MANILA_TEMPEST_CONCURRENCY
+echo "Running manila tempest tests:"
+tox -evenv-tempest -- tempest run -r $MANILA_TESTS -w $MANILA_TEMPEST_CONCURRENCY
 RETVAL=$?
 cd -
 
@@ -394,7 +375,7 @@ if [[ "$DRIVER" == "dummy" ]]; then
 
     echo "Running tempest manila test suites for DHSS=False mode"
     cd $BASE/new/tempest/
-    sudo -H -u $USER tempest run -r  $MANILA_TESTS --concurrency=$MANILA_TEMPEST_CONCURRENCY
+    tox -evenv-tempest -- tempest run -r $MANILA_TESTS -w $MANILA_TEMPEST_CONCURRENCY
     RETVAL2=$?
     cd -
     save_tempest_results 2
