@@ -20,6 +20,7 @@ import time
 
 from oslo_log import log
 from oslo_serialization import jsonutils
+from oslo_utils import encodeutils
 from oslo_utils import strutils
 import six
 from six.moves import http_client
@@ -54,6 +55,7 @@ API_VERSION_REQUEST_HEADER = 'X-OpenStack-Manila-API-Version'
 EXPERIMENTAL_API_REQUEST_HEADER = 'X-OpenStack-Manila-API-Experimental'
 
 V1_SCRIPT_NAME = '/v1'
+V2_SCRIPT_NAME = '/v2'
 
 
 class Request(webob.Request):
@@ -219,10 +221,11 @@ class Request(webob.Request):
         Microversions starts with /v2, so if a client sends a /v1 URL, then
         ignore the headers and request 1.0 APIs.
         """
-
-        if not self.script_name:
+        if not self.script_name or not (V1_SCRIPT_NAME in self.script_name or
+                                        V2_SCRIPT_NAME in self.script_name):
+            # The request is on the base URL without a major version specified
             self.api_version_request = api_version.APIVersionRequest()
-        elif self.script_name == V1_SCRIPT_NAME:
+        elif V1_SCRIPT_NAME in self.script_name:
             self.api_version_request = api_version.APIVersionRequest('1.0')
         else:
             if API_VERSION_REQUEST_HEADER in self.headers:
@@ -779,15 +782,21 @@ class Resource(wsgi.Application):
             msg = _("Malformed request body")
             return Fault(webob.exc.HTTPBadRequest(explanation=msg))
 
+        try:
+            method_name = meth.__qualname__
+        except AttributeError:
+            method_name = 'Controller: %s Method: %s' % (
+                six.text_type(self.controller), meth.__name__)
+
         if body:
+            decoded_body = encodeutils.safe_decode(body, errors='ignore')
             msg = ("Action: '%(action)s', calling method: %(meth)s, body: "
                    "%(body)s") % {'action': action,
-                                  'body': six.text_type(body),
-                                  'meth': six.text_type(meth)}
+                                  'body': decoded_body,
+                                  'meth': method_name}
             LOG.debug(strutils.mask_password(msg))
         else:
-            LOG.debug("Calling method '%(meth)s'",
-                      {'meth': six.text_type(meth)})
+            LOG.debug("Calling method '%(meth)s'", {'meth': method_name})
 
         # Now, deserialize the request body...
         try:
@@ -853,7 +862,7 @@ class Resource(wsgi.Application):
 
         try:
             msg_dict = dict(url=request.url, status=response.status_int)
-            msg = _("%(url)s returned with HTTP %(status)d") % msg_dict
+            msg = _("%(url)s returned with HTTP %(status)s") % msg_dict
         except AttributeError as e:
             msg_dict = dict(url=request.url, e=e)
             msg = _("%(url)s returned a fault: %(e)s") % msg_dict
@@ -864,7 +873,7 @@ class Resource(wsgi.Application):
             for hdr, val in response.headers.items():
                 val = utils.convert_str(val)
                 response.headers[hdr] = val
-
+            _set_request_id_header(request, response.headers)
             if not request.api_version_request.is_null():
                 response.headers[API_VERSION_REQUEST_HEADER] = (
                     request.api_version_request.get_string())
@@ -1023,6 +1032,7 @@ class Controller(object):
         if view_builder:
             self._view_builder = view_builder
         elif self._view_builder_class:
+            # pylint: disable=not-callable
             self._view_builder = self._view_builder_class()
         else:
             self._view_builder = None
