@@ -15,7 +15,7 @@
 from unittest import mock
 
 from lxml import etree
-from six.moves import urllib
+import requests
 
 from manila.share.drivers.netapp.dataontap.client import api
 
@@ -23,6 +23,7 @@ from manila.share.drivers.netapp.dataontap.client import api
 CONNECTION_INFO = {
     'hostname': 'hostname',
     'transport_type': 'https',
+    'ssl_cert_path': '/etc/ssl/certs/',
     'port': 443,
     'username': 'admin',
     'password': 'passw0rd',
@@ -2638,7 +2639,7 @@ FAKE_RESULT_API_ERRNO_VALID.add_attr('errno', '14956')
 FAKE_RESULT_SUCCESS = api.NaElement('result')
 FAKE_RESULT_SUCCESS.add_attr('status', 'passed')
 
-FAKE_HTTP_OPENER = urllib.request.build_opener()
+FAKE_HTTP_SESSION = requests.Session()
 
 FAKE_MANAGE_VOLUME = {
     'aggregate': SHARE_AGGREGATE_NAME,
